JsDoc Reference - AutoFill

Generated by JsDoc Toolkit 2.4.0 on Wed Dec 15 2010 21:56:49 GMT-0000 (GMT)
HTML template: Codeview

# Class AutoFill

AutoFill
Defined in: AutoFill.js.

Class Summary
Constructor Attributes | Constructor Name and Description
--- | ---
| AutoFill(DataTables, Configuration) AutoFill provides Excel like auto fill features for a DataTable

Field Summary
Field Attributes | Field Name and Description
--- | ---
<constant> | CLASS Name of this class
<static> <constant> | AutoFill.VERSION AutoFill version

Method Summary
Method Attributes | Method Name and Description
--- | ---
<private> | _fnAddColumn(i)
<private> | _fnColumnDefs(aoColumnDefs)
<private> | _fnColumnOptions(i, opts)
<private> | _fnColumnsAll(aoColumns)
<private> | _fnFillerDisplay(e) Display the drag handle on mouse over cell
<private> | _fnFillerDragMove(e) Mouse move event handler for during a move.
<private> | _fnFillerDragStart(e) Mouse down event handler for starting a drag
<private> | _fnFillerFinish(e) Mouse release handler - end the drag and take action to update the cells with the needed values
<private> | _fnFillerPosition(nTd) Position the filler icon over a cell
<private> | _fnInit(oDT, oConfig) Initialisation
<private> | _fnPrep(sStr) Chunk a string such that it can be filled in by the stepper function
<private> | _fnReadCell(nTd) Read informaiton from a cell, possibly using live DOM elements if suitable
<private> | _fnStep(nTd, oPrepped, iDiff, bIncrement, sToken) Render a string for it's position in the table after the drag (incrememt numbers)
<private> | _fnTargetCoords(nTd) Find out the coordinates of a given TD cell in a table
<private> | _fnUpdateBorder(nStart, nEnd) Display the border around one or more cells (from start to end)
<private> | _fnWriteCell(nTd, sVal, bLast) Write informaiton to a cell, possibly using live DOM elements if suitable
| fnSettings() Retreieve the settings object from an instance

Class Detail
AutoFill(DataTables, Configuration)
AutoFill provides Excel like auto fill features for a DataTable

Parameters:
{object} DataTables
  settings object
{object} Configuration
  object for AutoFill

Field Detail
<constant> {String} CLASS
Name of this class

Default Value:
  AutoFill

<static> <constant> {String} AutoFill.VERSION
AutoFill version

Default Value:
  1.1.1

Method Detail
<private> _fnAddColumn(i)

Parameters:
i

<private> _fnColumnDefs(aoColumnDefs)

Parameters:
aoColumnDefs

<private> _fnColumnOptions(i, opts)

Parameters:
i
opts

<private> _fnColumnsAll(aoColumns)

Parameters:
aoColumns

<private> _fnFillerDisplay(e)
Display the drag handle on mouse over cell

Parameters:
{Object} e
  Event object

Returns:
  void

<private> _fnFillerDragMove(e)
Mouse move event handler for during a move. See if we want to update the display based on the new cursor position

Parameters:
{Object} e
  Event object

Returns:
  void

<private> _fnFillerDragStart(e)
Mouse down event handler for starting a drag

Parameters:
{Object} e
  Event object

Returns:
  void

<private> _fnFillerFinish(e)
Mouse release handler - end the drag and take action to update the cells with the needed values

Parameters:
{Object} e
  Event object

Returns:
  void

<private> _fnFillerPosition(nTd)
Position the filler icon over a cell

Parameters:
{Node} nTd
  Cell to position filler icon over

Returns:
  void

<private> _fnInit(oDT, oConfig)
Initialisation

Parameters:
{object} oDT
  DataTables settings object
{object} oConfig
  Configuration object for AutoFill

Returns:
  void

<private> {Object} _fnPrep(sStr)
Chunk a string such that it can be filled in by the stepper function

Parameters:
{String} sStr
  String to prep

Returns:
  {Object} with parameters, iStart, sStr and sPostFix

<private> {String} _fnReadCell(nTd)
Read informaiton from a cell, possibly using live DOM elements if suitable

Parameters:
{Node} nTd
  Cell to read

Returns:
  {String} Read value

<private> {String} _fnStep(nTd, oPrepped, iDiff, bIncrement, sToken)
Render a string for it's position in the table after the drag (incrememt numbers)

Parameters:
{Node} nTd
  Cell being written to
{Object} oPrepped
  Prepared object for the stepper (from _fnPrep)
{Int} iDiff
  Step difference
{Boolean} bIncrement
  Increment (true) or decriment (false)
{String} sToken
  Token to replace

Returns:
  {String} Rendered information

<private> {Object} _fnTargetCoords(nTd)
Find out the coordinates of a given TD cell in a table

Parameters:
{Node} nTd

Returns:
  {Object} x and y properties, for the position of the cell in the tables DOM

<private> _fnUpdateBorder(nStart, nEnd)
Display the border around one or more cells (from start to end)

Parameters:
{Node} nStart
  Starting cell
{Node} nEnd
  Ending cell

Returns:
  void

<private> _fnWriteCell(nTd, sVal, bLast)
Write informaiton to a cell, possibly using live DOM elements if suitable

Parameters:
{Node} nTd
  Cell to write
{String} sVal
  Value to write
{Boolean} bLast
  Flag to show if this is that last update

Returns:
  void

{object} fnSettings()
Retreieve the settings object from an instance

Returns:
  {object} AutoFill settings object